@@ -17,16 +17,17 @@
 
 #include "track.h"
 
-Track::Track(guint32 duration, Glib::ustring genre, Glib::ustring song_title, Glib::ustring artist_name, guint32 album_id, guint32 track_id)
+Track::Track(guint32 duration, Glib::ustring genre, Glib::ustring song_title, Glib::ustring artist_name, guint32 album_id, guint32 track_id, Glib::ustring license)
   :d_duration(duration), d_genre(genre), d_song_title(song_title), 
-    d_artist_name(artist_name), d_album_id(album_id), d_track_id(track_id)
+    d_artist_name(artist_name), d_album_id(album_id), d_track_id(track_id),
+    d_license(license)
 {
 }
 
 Track::Track(const Track& t)
   :d_duration(t.d_duration), d_genre(t.d_genre), d_song_title(t.d_song_title),
     d_artist_name(t.d_artist_name), d_album_id(t.d_album_id), 
-    d_track_id(t.d_track_id)
+    d_track_id(t.d_track_id), d_license(t.d_license)
 {
 }
 
